                   FUNCTION:NAME
                          :BEGIN 
             0  1  2  3  4  5  6  7  8  9  a  b  c  d  e  f  0123456789abcdef
         0: 64 74 72 61 63 65 34 12 21 43                    dtrace4.!C


-- @@stderr --
dtrace: script 'test/unittest/actions/trace/tst.array.d' matched 1 probe
